Less announcing, more change-logging
------------------------------------

With version 2.5.0 we dropped creating special announcement documents and rely on communicating
all relevant changes through the
`CHANGELOG <https://github.com/tox-dev/tox/blob/master/CHANGELOG.rst>`_. See at
`PyPI <https://pypi.org/project/tox/>`_ for a rendered version of the last changes containing
links to the important issues and pull requests that were integrated into the release.

The historic release announcements are still online here for various versions:

* `0.5 <https://tox.readthedocs.io/en/2.4.0/announce/release-0.5.html>`_,
* `1.0 <https://tox.readthedocs.io/en/2.4.0/announce/release-1.0.html>`_,
* `1.1 <https://tox.readthedocs.io/en/2.4.0/announce/release-1.1.html>`_,
* `1.2 <https://tox.readthedocs.io/en/2.4.0/announce/release-1.2.html>`_,
* `1.3 <https://tox.readthedocs.io/en/2.4.0/announce/release-1.3.html>`_,
* `1.4 <https://tox.readthedocs.io/en/2.4.0/announce/release-1.4.html>`_,
* `1.4.3 <https://tox.readthedocs.io/en/2.4.0/announce/release-1.4.3.html>`_,
* `1.8 <https://tox.readthedocs.io/en/2.4.0/announce/release-1.8.html>`_,
* `1.9 <https://tox.readthedocs.io/en/2.4.0/announce/release-1.9.html>`_,
* `2.0 <https://tox.readthedocs.io/en/2.4.0/announce/release-2.0.html>`_,
* `2.4.0 <https://tox.readthedocs.io/en/2.4.0/announce/release-2.4.0.html>`_.


Happy testing,
The tox maintainers
